==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/GetPrefetchScheduleRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetPrefetchScheduleRequest(
    name: __string,
    playbackConfigurationName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.GetPrefetchScheduleRequest = {
    import GetPrefetchScheduleRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.GetPrefetchScheduleRequest
      .builder()
      .name(__string.unwrap(name): java.lang.String)
      .playbackConfigurationName(
        __string.unwrap(playbackConfigurationName): java.lang.String
      )
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.GetPrefetchScheduleRequest.ReadOnly =
    zio.aws.mediatailor.model.GetPrefetchScheduleRequest.wrap(buildAwsValue())
}
object GetPrefetchScheduleRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.GetPrefetchScheduleRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.GetPrefetchScheduleRequest =
      zio.aws.mediatailor.model
        .GetPrefetchScheduleRequest(name, playbackConfigurationName)
    def name: __string
    def playbackConfigurationName: __string
    def getName: ZIO[Any, Nothing, __string] = ZIO.succeed(name)
    def getPlaybackConfigurationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(playbackConfigurationName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.GetPrefetchScheduleRequest
  ) extends zio.aws.mediatailor.model.GetPrefetchScheduleRequest.ReadOnly {
    override val name: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.name())
    override val playbackConfigurationName: __string =
      zio.aws.mediatailor.model.primitives
        .__string(impl.playbackConfigurationName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.GetPrefetchScheduleRequest
  ): zio.aws.mediatailor.model.GetPrefetchScheduleRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.19.7.5-sources.jar: zio/aws/mediatailor/model/GetPrefetchScheduleRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetPrefetchScheduleRequest(
    name: __string,
    playbackConfigurationName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.GetPrefetchScheduleRequest = {
    import GetPrefetchScheduleRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.GetPrefetchScheduleRequest
      .builder()
      .name(name: java.lang.String)
      .playbackConfigurationName(playbackConfigurationName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.GetPrefetchScheduleRequest.ReadOnly =
    zio.aws.mediatailor.model.GetPrefetchScheduleRequest.wrap(buildAwsValue())
}
object GetPrefetchScheduleRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.GetPrefetchScheduleRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.GetPrefetchScheduleRequest =
      zio.aws.mediatailor.model
        .GetPrefetchScheduleRequest(name, playbackConfigurationName)
    def name: __string
    def playbackConfigurationName: __string
    def getName: ZIO[Any, Nothing, __string] = ZIO.succeed(name)
    def getPlaybackConfigurationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(playbackConfigurationName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.GetPrefetchScheduleRequest
  ) extends zio.aws.mediatailor.model.GetPrefetchScheduleRequest.ReadOnly {
    override val name: __string = impl.name(): __string
    override val playbackConfigurationName: __string =
      impl.playbackConfigurationName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.GetPrefetchScheduleRequest
  ): zio.aws.mediatailor.model.GetPrefetchScheduleRequest.ReadOnly =
    new Wrapper(impl)
}
